write_dependencies: Write dependency packages to DESCRIPTION.

Description Usage Arguments Details Examples

View source: R/write_dependencies.r

Description

Scans all files in R/ for used packages (searching for :: syntax) and scans NAMESPACE file for import and importFrom statements. Then writes dependencies to Imports section in DESCRIPTION file.

Usage

1
write_dependencies(pkg = ".")

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.

Details

Make sure to import all dependencies or use the explicit :: syntax when calling functions from other packages and to generate the NAMESPACE first.

Examples

1
2
3
4
## Not run: 
write_dependencies()

## End(Not run)

markusdumke/pkghelper documentation built on Oct. 22, 2019, 6:16 p.m.