Description Usage Arguments Details Examples
View source: R/write_dependencies.r
Scans all files in R/ for used packages (searching for :: syntax) and scans
NAMESPACE file for import and importFrom statements.
Then writes dependencies to Imports section in DESCRIPTION file.
1 | write_dependencies(pkg = ".")
|
pkg |
The package to use, can be a file path to the package or a
package object. See |
Make sure to import all dependencies or use the explicit :: syntax when
calling functions from other packages and to generate the NAMESPACE first.
1 2 3 4 | ## Not run:
write_dependencies()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.